==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_my.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=my
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>အရေးကြီးသောအုပ်စု</b> အစုထဲမှ သော့ချက်စကားလုံးများကို ရွေးချယ်ရန် လေးလေးနက်နက် အကြံပြုချက်ဖြစ်သည်',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'ဝက်ဘ်ဆိုက်ကြီးကြပ်သူ',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'စာတည်းများ',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'ဖိုရမ်တွင် မှာကြားချက်များထားရှိပြီး အများသုံးဝက်ဘ်ဆိုက်သို့ ဝင်ရောက်ကြည့်ရှုသူများ',

	// I
	'icone_creation_groupe_mots' => 'သော့ချက်စကားလုံး အုပ်စုအသစ်တည်ဆောက်ပါ',
	'icone_creation_mots_cles' => 'သော့ချက်စကားလုံး အသစ်တည်ဆောက်ပါ',
	'icone_modif_groupe_mots' => 'ဤသော့ချက် စကားလုံးအုပ်စုကို ပြန်လည်မွမ်းမံပါ',
	'icone_mots_cles' => 'စကားစုများ',
	'icone_supprimer_groupe_mots' => 'ဤအုပ်စုကို ဖျက်ပစ်ပါ',
	'icone_voir_tous_mots_cles' => 'သော့ချက်စကားလုံးများကို ပြပါ',
	'info_articles_lies_mot' => 'ဆောင်းပါးများကို ဤသော့ချက်စကားလုံးများနှင့် ပေါင်းစည်းပါ',
	'info_changer_nom_groupe' => 'ဤ​အုပ်စုအမည်ကို ပြောင်းပါ',
	'info_creation_mots_cles' => 'နေရာတွင် ဝက်ဘ်ဆိုက် သော့ချက်စကားလုံးများ တည်ဆောက်ရန်နှင့်ညှိရန်',
	'info_dans_groupe' => 'အုပ်စုထဲတွင်',
	'info_delet_mots_cles' => 'သော့ချက်စကားလုံး ဖျက်ရန်လိုအပ်ပါသည်<b>@titre_mot@</b> (@type_mot@) ဤသော့ချက်စကားလုံးသည်
<b>@texte_lie@</b>သို့ ချိတ်ဆက်ထားပြီးဖြစ်သည်။ သင့်ဆုံးဖြတ်ချက်ကို အတည်ပြုပါ', # MODIF
	'info_groupe_important' => 'အရေးပါသောအုပ်စု',
	'info_mots_cles' => 'သော့ချက်စကားလုံးများ',
	'info_mots_cles_association' => 'ဤအုပ်စုရှိ သော့ချက်စကားလုံးများသည် ()နှင့် ပေါင်းစည်းနိုင်သည်',
	'info_oui_suppression_mot_cle' => 'သည်သော့ချက်စကားလုံးများကို အမြဲတမ်းဖျက်ပစ်ချင်သည်',
	'info_question_mots_cles' => 'သင့်ဝက်ဘ်ဆိုက်တွင် သော့ချက်စကားလုံးများကို အသုံးပြုချင်ပါသလား',
	'info_qui_attribue_mot_cle' => 'ဤအုပ်စုရှိ သော့ချက်စကားလုံးများကို ()ဖြင့် သတ်မှတ်နိုင်ပါသည်',
	'info_retirer_mot' => 'ဤစကားစုများကို ပယ်ဖျက်ရန်',
	'info_retirer_mots' => 'ဤစကားစုများအားလုံးကို ပယ်ဖျက်ရန်',
	'info_rubriques_liees_mot' => 'အပိုင်းကဏ္ဍသည် ဤသော့ချက်စကားနှင့် သင့်လျော်သည်',
	'info_selection_un_seul_mot_cle' => 'ဤအုပ်စုမှ တစ်ကြိမ်လျှင်<b>သော့ချက်စကားလုံးတစ်လုံးကိုသာ</b> သင်ရွေးချယ်ခွင့်ရသည် ', # MODIF
	'info_supprimer_mot' => 'ဤသော့ချက်စကားလုံးကို ဖျက်ပစ်ပါ',
	'info_titre_mot_cle' => 'ဤ သော့ချက်စကားလုံး၏ အမည် (သို့)​ ခေါင်းစဉ်',
	'info_un_mot' => 'တကြိမ်တွင်သုံးသော သော့ချက်စကားလုံးတခု',
	'item_ajout_mots_cles' => 'ဖိုရမ်များတွင် သော့ချက်စကားလုံးများ ထပ်ပေါင်းခြင်းကို ခွင့်ပြုသည်',
	'item_non_ajout_mots_cles' => 'ဖိုရမ်များထဲသို့ သော့ချက်စကားလုံးများ ထပ်ထည့်ခွင့်မပြုပါ',
	'item_non_utiliser_config_groupe_mots_cles' => 'အဆင့်မြင့် သော့ချက်စကားလုံးများ ဆက်သွယ်တပ်ဆင်မှုကို မသုံးပါနှင့်',
	'item_non_utiliser_mots_cles' => 'သော့ချက်စကားစုများကို မသုံးပါနှင့်',
	'item_utiliser_config_groupe_mots_cles' => 'အဆင့်မြင့် သော့ချက်စကားလုံး ဆက်သွယ်တပ်ဆင်မှုကိုသုံးပါ',
	'item_utiliser_mots_cles' => 'သော့ချက်စကားစုများကိုသုံးပါ',

	// L
	'logo_mot_cle' => 'သော့ချက်စကားလုံးများ၏လိုဂို',

	// T
	'texte_config_groupe_mots_cles' => 'အရေးပါသော အုပ်စုတစုမှ သီးသန့်စကားစုတစုကို ​​ရွေးချယ်နိုင်ရန် သော့ချက်စကားလုံးများ အဆင့်မြှင့် စီမံလုပ်ဆောင်မှုကို အသက်သွင်းလိုပါသလား?', # MODIF
	'texte_mots_cles' => 'သော့ချက်စကားစုများသည် ဆောင်းပါးများနှင့် သက်ဆိုင်ရာ အခန်းကဏ္ဍများ၏ ခေါင်းစဉ်အလိုက် ချိတ်ဆက်မှု လိပ်စာများကို ဖန်တီးခွင့်ပြုသည်။ ဤသို့လုပ်ဆောင်နိုင်ခြင်းသည် သင့်ဝက်ဘ်ဆိုက်ကို ပိုမိုအသက်ဝင်အောင် စိတ်ကြိုက်ဖန်တီးနိုင်စွမ်းကိုလည်း ​ရရှိစေပါသည်။',
	'texte_mots_cles_dans_forum' => 'လူထုဝက်ဘ်ဆိုက်ဖိုရမ်အတွင်း အလည်လာရောက်သူများမှ ရွေးချယ်နိုင်သော စကားစုကို သင်ခွင့်ပြုလိုသလား
(သတိပေးချက်- ဤရွေးချယ်ရန် အခွင့်လမ်းကို မှန်ကန်စွာ အသုံးပြုနိုင်ရန်အတွက် အခက်ခဲ အနည်းငယ်ရှိပါသည်)',
	'texte_nouveau_mot' => 'သော့ချက်စကားလုံး​အသစ်',
	'titre_config_groupe_mots_cles' => 'သော့ချက်စကားလုံးအုပ်စုများ ဆက်သွယ်တပ်ဆင်မှု',
	'titre_gauche_mots_edit' => 'သော့ချက်စကားလုံးနံပါတ်',
	'titre_mots_cles_dans_forum' => 'အများသုံး ဝက်ဘ်ဆိုက်ဖိုရမ်ထဲရှိ သော့ချက်စကားလုံးများ',
	'titre_mots_tous' => 'သော့ချက်စကားလုံးများ',
	'titre_nouveau_groupe' => 'အုပ်စုအသစ်',
	'titre_page_mots_tous' => 'သော့ချက်စကားလုံးများ'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_my.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=my
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>အရေးကြီးသောအုပ်စု</b> အစုထဲမှ သော့ချက်စကားလုံးများကို ရွေးချယ်ရန် လေးလေးနက်နက် အကြံပြုချက်ဖြစ်သည်',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'ဝက်ဘ်ဆိုက်ကြီးကြပ်သူ',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'စာတည်းများ',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'ဖိုရမ်တွင် မှာကြားချက်များထားရှိပြီး အများသုံးဝက်ဘ်ဆိုက်သို့ ဝင်ရောက်ကြည့်ရှုသူများ',

	// I
	'icone_creation_groupe_mots' => 'သော့ချက်စကားလုံး အုပ်စုအသစ်တည်ဆောက်ပါ',
	'icone_creation_mots_cles' => 'သော့ချက်စကားလုံး အသစ်တည်ဆောက်ပါ',
	'icone_modif_groupe_mots' => 'ဤသော့ချက် စကားလုံးအုပ်စုကို ပြန်လည်မွမ်းမံပါ',
	'icone_mots_cles' => 'စကားစုများ',
	'icone_supprimer_groupe_mots' => 'ဤအုပ်စုကို ဖျက်ပစ်ပါ',
	'icone_voir_tous_mots_cles' => 'သော့ချက်စကားလုံးများကို ပြပါ',
	'info_articles_lies_mot' => 'ဆောင်းပါးများကို ဤသော့ချက်စကားလုံးများနှင့် ပေါင်းစည်းပါ',
	'info_changer_nom_groupe' => 'ဤ​အုပ်စုအမည်ကို ပြောင်းပါ',
	'info_creation_mots_cles' => 'နေရာတွင် ဝက်ဘ်ဆိုက် သော့ချက်စကားလုံးများ တည်ဆောက်ရန်နှင့်ညှိရန်',
	'info_dans_groupe' => 'အုပ်စုထဲတွင်',
	'info_delet_mots_cles' => 'သော့ချက်စကားလုံး ဖျက်ရန်လိုအပ်ပါသည်<b>@titre_mot@</b> (@type_mot@) ဤသော့ချက်စကားလုံးသည်
<b>@texte_lie@</b>သို့ ချိတ်ဆက်ထားပြီးဖြစ်သည်။ သင့်ဆုံးဖြတ်ချက်ကို အတည်ပြုပါ', # MODIF
	'info_groupe_important' => 'အရေးပါသောအုပ်စု',
	'info_mots_cles' => 'သော့ချက်စကားလုံးများ',
	'info_mots_cles_association' => 'ဤအုပ်စုရှိ သော့ချက်စကားလုံးများသည် ()နှင့် ပေါင်းစည်းနိုင်သည်',
	'info_oui_suppression_mot_cle' => 'သည်သော့ချက်စကားလုံးများကို အမြဲတမ်းဖျက်ပစ်ချင်သည်',
	'info_question_mots_cles' => 'သင့်ဝက်ဘ်ဆိုက်တွင် သော့ချက်စကားလုံးများကို အသုံးပြုချင်ပါသလား',
	'info_qui_attribue_mot_cle' => 'ဤအုပ်စုရှိ သော့ချက်စကားလုံးများကို ()ဖြင့် သတ်မှတ်နိုင်ပါသည်',
	'info_retirer_mot' => 'ဤစကားစုများကို ပယ်ဖျက်ရန်',
	'info_retirer_mots' => 'ဤစကားစုများအားလုံးကို ပယ်ဖျက်ရန်',
	'info_rubriques_liees_mot' => 'အပိုင်းကဏ္ဍသည် ဤသော့ချက်စကားနှင့် သင့်လျော်သည်',
	'info_selection_un_seul_mot_cle' => 'ဤအုပ်စုမှ တစ်ကြိမ်လျှင်<b>သော့ချက်စကားလုံးတစ်လုံးကိုသာ</b> သင်ရွေးချယ်ခွင့်ရသည် ', # MODIF
	'info_supprimer_mot' => 'ဤသော့ချက်စကားလုံးကို ဖျက်ပစ်ပါ',
	'info_titre_mot_cle' => 'ဤ သော့ချက်စကားလုံး၏ အမည် (သို့)​ ခေါင်းစဉ်',
	'info_un_mot' => 'တကြိမ်တွင်သုံးသော သော့ချက်စကားလုံးတခု',
	'item_ajout_mots_cles' => 'ဖိုရမ်များတွင် သော့ချက်စကားလုံးများ ထပ်ပေါင်းခြင်းကို ခွင့်ပြုသည်',
	'item_non_ajout_mots_cles' => 'ဖိုရမ်များထဲသို့ သော့ချက်စကားလုံးများ ထပ်ထည့်ခွင့်မပြုပါ',
	'item_non_utiliser_config_groupe_mots_cles' => 'အဆင့်မြင့် သော့ချက်စကားလုံးများ ဆက်သွယ်တပ်ဆင်မှုကို မသုံးပါနှင့်',
	'item_non_utiliser_mots_cles' => 'သော့ချက်စကားစုများကို မသုံးပါနှင့်',
	'item_utiliser_config_groupe_mots_cles' => 'အဆင့်မြင့် သော့ချက်စကားလုံး ဆက်သွယ်တပ်ဆင်မှုကိုသုံးပါ',
	'item_utiliser_mots_cles' => 'သော့ချက်စကားစုများကိုသုံးပါ',

	// L
	'logo_mot_cle' => 'သော့ချက်စကားလုံးများ၏လိုဂို',

	// T
	'texte_config_groupe_mots_cles' => 'အရေးပါသော အုပ်စုတစုမှ သီးသန့်စကားစုတစုကို ​​ရွေးချယ်နိုင်ရန် သော့ချက်စကားလုံးများ အဆင့်မြှင့် စီမံလုပ်ဆောင်မှုကို အသက်သွင်းလိုပါသလား?', # MODIF
	'texte_mots_cles' => 'သော့ချက်စကားစုများသည် ဆောင်းပါးများနှင့် သက်ဆိုင်ရာ အခန်းကဏ္ဍများ၏ ခေါင်းစဉ်အလိုက် ချိတ်ဆက်မှု လိပ်စာများကို ဖန်တီးခွင့်ပြုသည်။ ဤသို့လုပ်ဆောင်နိုင်ခြင်းသည် သင့်ဝက်ဘ်ဆိုက်ကို ပိုမိုအသက်ဝင်အောင် စိတ်ကြိုက်ဖန်တီးနိုင်စွမ်းကိုလည်း ​ရရှိစေပါသည်။',
	'texte_mots_cles_dans_forum' => 'လူထုဝက်ဘ်ဆိုက်ဖိုရမ်အတွင်း အလည်လာရောက်သူများမှ ရွေးချယ်နိုင်သော စကားစုကို သင်ခွင့်ပြုလိုသလား
(သတိပေးချက်- ဤရွေးချယ်ရန် အခွင့်လမ်းကို မှန်ကန်စွာ အသုံးပြုနိုင်ရန်အတွက် အခက်ခဲ အနည်းငယ်ရှိပါသည်)',
	'texte_nouveau_mot' => 'သော့ချက်စကားလုံး​အသစ်',
	'titre_config_groupe_mots_cles' => 'သော့ချက်စကားလုံးအုပ်စုများ ဆက်သွယ်တပ်ဆင်မှု',
	'titre_gauche_mots_edit' => 'သော့ချက်စကားလုံးနံပါတ်',
	'titre_mots_cles_dans_forum' => 'အများသုံး ဝက်ဘ်ဆိုက်ဖိုရမ်ထဲရှိ သော့ချက်စကားလုံးများ',
	'titre_mots_tous' => 'သော့ချက်စကားလုံးများ',
	'titre_nouveau_groupe' => 'အုပ်စုအသစ်',
	'titre_page_mots_tous' => 'သော့ချက်စကားလုံးများ',
];
